@@ -1,6 +1,7 @@
 #
 # Copyright (c) 2020-2021 Pinecone Systems Inc. All right reserved.
 #
+import logging
 
 import dns.resolver
 import sentry_sdk
@@ -10,7 +11,9 @@ import inspect
 from functools import wraps
 
 from pinecone.core.utils.constants import PACKAGE_ENVIRONMENT, SENTRY_DSN_TXT_RECORD
-from pinecone.config import logger
+
+
+_logger = logging.getLogger(__name__)
 
 
 def sentry_decorator(func):
@@ -35,7 +38,7 @@ def init_sentry():
     The Sentry DSN is stored as a txt record.
     """
     if not sentry_sdk.Hub.current.client:
-        logger.info("Sentry is not initialized.")
+        _logger.info("Sentry is not initialized.")
         # sentry is not initialized
         sentry_dsn = None
         try:
@@ -44,7 +47,7 @@ def init_sentry():
                 sentry_dsn = json.loads(res.to_text())
                 break
         except Exception:
-            logger.warning("Unable to resolve Sentry DSN.")
+            _logger.warning("Unable to resolve Sentry DSN.")
         if sentry_dsn:
             debug = os.getenv("SENTRY_DEBUG") == "True"
             sentry_sdk.init(dsn=sentry_dsn, debug=debug, environment=PACKAGE_ENVIRONMENT, traces_sample_rate=0.1)
